@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  *          Anders Carlsson <andersca@gnu.org>
@@ -45,7 +45,7 @@ static GtkWidget *cred_dialog;
 static void zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data);
 
 /* Sync with the people in the THANKS file */
-static const gchar *author_credits[] = {
+static const gchar *const author_credits[] = {
   "Authors",
   "=======",
   "Glynn Foster <glynn foster sun com>",
@@ -90,6 +90,8 @@ static const gchar *author_credits[] = {
   "Hidetoshi Tajima  <hidetoshi tajima sun com>",
   "Tom Tromey  <tromey redhat com>",
   "Yann  <bloch iie cnam fr>",
+  "Norman Rasmussen <normanr gmail com>",
+  "Benoît Dejean <tazforever dlfp org>",
   "",
   "And all the translators that rock my world",
   "==========================================",
@@ -168,10 +170,24 @@ static const gchar *author_credits[] = {
   "Daniel Yacob  <locales geez org>",
   "Funda Wang <fundawang linux net cn>",
   "Alexander Winston  <alexander winston comcast net>",
+  "Theppitak Karoonboonyanan <thep linux thai net>",
+  "Martin Willemoes Hansen <mwh sysrq dk>",
+  "Ignacio Casal Quinteiro <nacho.resa gmail com>",
+  "Pawan Chitrakar <pawan nplinux org>",
+  "Rajesh Ranjan <rajeshkajha yahoo org>",
+  "Vladimir Petkov <vpetkov i-space org>",
+  "Abduxukur Abdurixit <abduxukur.abdurixit t-systems ch>",
+  "Adi Attar <aattar cvs gnome org>",
+  "Steve Murphy <murf e-tools com>",
+  "Josep Puigdemont <josep imatge-sintetica com>",
+  "Adam Weinberger <adamw gnome org>",
+  "Ivar Smolin <okul linux ee>",
+  "Jens Seidel <jensseidel users sf net>",
+  "Benoît Dejean <tazforever dlfp org>",
   NULL
 };
 
-gchar *translator_credits;
+static gchar *translator_credits;
 
 static gint
 zenity_move_clothes_event (GnomeCanvasItem *item, 
@@ -229,7 +245,7 @@ typedef struct
   gdouble x, y;
 } MonkClothes;
 
-static MonkClothes monk_clothes[] = {
+static const MonkClothes monk_clothes[] = {
   {"gnome-tshirt.png", 30.0, 20.0},
   {"sunglasses.png", ZENITY_CANVAS_X - 100.0 , ZENITY_CANVAS_Y - 150.0 },
   {"surfboard.png", 30.0, ZENITY_CANVAS_Y - 200.0},
@@ -242,7 +258,7 @@ zenity_create_clothes (GtkWidget *canvas_board)
   GdkPixbuf *pixbuf;
   GnomeCanvasItem *canvas_item;
   gchar *pixbuf_path;
-  gint i;
+  size_t i;
 
   for (i = 0; i < G_N_ELEMENTS (monk_clothes); i++) {
     pixbuf_path = g_strconcat (ZENITY_CLOTHES_PATH, monk_clothes[i].filename, NULL); 
@@ -544,7 +560,6 @@ static void
 zenity_about_dialog_response (GtkWidget *widget, int response, gpointer data)
 {
   ZenityData *zen_data = data;
-  GError *error = NULL;
 
   switch (response) {
     case GTK_RESPONSE_OK:
